==> apache-tinkerpop-3.6.4-src.zip: tinkerpop-3.6.4/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphSON/VertexPropertySerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.Collections.Generic;

namespace Gremlin.Net.Structure.IO.GraphSON
{
    internal class VertexPropertySerializer : IGraphSONSerializer
    {
        public Dictionary<string, dynamic> Dictify(dynamic objectData, GraphSONWriter writer)
        {
            VertexProperty vertexProperty = objectData;
            var valueDict = new Dictionary<string, dynamic>
            {
                {"id", writer.ToDict(vertexProperty.Id)},
                {"label", vertexProperty.Label},
                {"value", writer.ToDict(vertexProperty.Value)},
                {"vertex", writer.ToDict(vertexProperty.Vertex.Id)}
            };
            return GraphSONUtil.ToTypedValue(nameof(VertexProperty), valueDict);
        }
    }
}

==> apache-tinkerpop-3.8.0-src.zip: tinkerpop-3.8.0/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphSON/VertexPropertySerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.Collections.Generic;

namespace Gremlin.Net.Structure.IO.GraphSON
{
    internal class VertexPropertySerializer : IGraphSONSerializer
    {
        public Dictionary<string, dynamic> Dictify(dynamic objectData, GraphSONWriter writer)
        {
            VertexProperty vertexProperty = objectData;
            var valueDict = new Dictionary<string, dynamic>
            {
                {"id", writer.ToDict(vertexProperty.Id)},
                {"label", vertexProperty.Label},
                {"value", writer.ToDict(vertexProperty.Value)}
            };
            if (vertexProperty.Vertex != null)
            {
                valueDict.Add("vertex", writer.ToDict(vertexProperty.Vertex.Id));
            }
            return GraphSONUtil.ToTypedValue(nameof(VertexProperty), valueDict);
        }
    }
}
